From 36163e2377e775d1322ab6b71f2893a4e5c1984f Mon Sep 17 00:00:00 2001
From: Jelte Fennema-Nio <jelte.fennema@microsoft.com>
Date: Mon, 19 Feb 2024 16:06:05 +0100
Subject: [PATCH v4 3/5] Bring .editorconfig fully in sync with .gitattributes

This adds the final lines from .gitattributes to .editorconfig. It
shouldn't matter for most people, because these lines are for generated
or elsewhere maintained files. Still it seems be nice for these files
not to be reformated if someone opens them in their editor and then
presses save.
---
 .editorconfig | 43 +++++++++++++++++++++++++++++++++++++++++++
 1 file changed, 43 insertions(+)

diff --git a/.editorconfig b/.editorconfig
index 92a16bd5de..c742e0f844 100644
--- a/.editorconfig
+++ b/.editorconfig
@@ -9,6 +9,12 @@ indent_style = tab
 indent_size = tab
 tab_width = 4
 
+[*.po]
+# This does not provide indent_size since .po files don't have indentation.
+# Setting indent_style is only done to prevent accidental insertion of tabs.
+indent_style = space
+insert_final_newline = unset
+
 [*.{sgml,xml}]
 indent_style = space
 indent_size = 1
@@ -36,3 +42,40 @@ insert_final_newline = unset
 [src/interfaces/ecpg/test/expected/*]
 trim_trailing_whitespace = false
 insert_final_newline = unset
+
+# These files are maintained or generated elsewhere.  We take them as is.
+[configure]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[ppport.h]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/backend/regex/COPYRIGHT]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/backend/snowball/libstemmer/*.c]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/backend/utils/mb/Unicode/*-std.txt]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/include/snowball/libstemmer/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/timezone/data/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/tools/pg_bsd_indent/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/tools/pg_bsd_indent/tests/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
-- 
2.34.1

